@@ -32,7 +32,7 @@ import com.verisign.epp.codec.rgpext.EPPRgpExtUpdate;
 import com.verisign.epp.codec.syncext.EPPSyncExtUpdate;
 import com.verisign.epp.codec.whois.EPPWhoisInf;
 import com.verisign.epp.interfaces.EPPCommandException;
-import com.verisign.epp.interfaces.EPPDomain;
+import com.verisign.epp.interfaces.EPPRelatedDomain;
 import com.verisign.epp.interfaces.EPPSession;
 
 /**
@@ -40,7 +40,7 @@ import com.verisign.epp.interfaces.EPPSession;
  * <code>EPPDomain</code> by adding new operations like 
  * restore request, restore report, and sync.   
  */
-public class NSDomain extends EPPDomain {
+public class NSDomain extends EPPRelatedDomain {
 	
 	/**
 	 * Restore report information
